@@ -39,7 +39,7 @@ __all__ = [
 # Program entry point
 @click.group()
 @click.version_option(SuperHelper.Version, prog_name=SuperHelper.AppName, message=version_message)
-@click.option("--debug", help="Enable debug mode", default=False, is_flag=True)
+@click.option("--debug", help="Enable debug mode.", default=False, is_flag=True)
 def cli(debug) -> None:
     """Executes SuperHelper tools."""
     SuperHelper.set_debug_mode(debug)
@@ -79,10 +79,10 @@ def load_core_commands():
         try:
             cli.add_command(core_module[0])
         except Exception or BaseException:
-            logger.exception(f"Unable to load core module {core_module[1]}")
+            logger.exception(f"Unable to load core command {core_module[1]}")
             sys.exit(1)
         else:
-            logger.debug(f"Loaded core module {core_module[1]}")
+            logger.debug(f"Loaded core command {core_module[1]}")
 
 
 def load_added_modules():
